==> haskell-iproute-1.7.15-48-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-iproute.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 iproute
version:              1.7.15
visibility:           public
id:                   iproute-1.7.15-FrO0nPBaiAtBvgC8c1wweb
key:                  iproute-1.7.15-FrO0nPBaiAtBvgC8c1wweb
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             http://www.mew.org/~kazu/proj/iproute/
synopsis:             IP Routing Table
description:
    IP Routing Table is a tree of IP ranges
    to search one of them on the longest
    match base. It is a kind of TRIE with one
    way branching removed. Both IPv4 and IPv6
    are supported.

category:             Algorithms, Network
abi:                  f4f5fc19817a1e08478d100522e66e84
exposed:              True
exposed-modules:
    Data.IP Data.IP.Builder Data.IP.Internal Data.IP.RouteTable
    Data.IP.RouteTable.Internal

hidden-modules:       Data.IP.Addr Data.IP.Mask Data.IP.Op Data.IP.Range
import-dirs:          /usr/lib/ghc-9.4.8/site-local/iproute-1.7.15
library-dirs:         /usr/lib/ghc-9.4.8/site-local/iproute-1.7.15
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/iproute-1.7.15
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-iproute
hs-libraries:         HSiproute-1.7.15-FrO0nPBaiAtBvgC8c1wweb
depends:
    appar-0.1.8-GWpFBSBbC0w8yHmWJHobgf base-4.17.2.1
    byteorder-1.0.4-GnZZPnCtMLjHLa4McP5dl3 bytestring-0.11.5.3
    containers-0.6.7 network-3.1.4.0-Aot7Hsnd3no7HIoU7vrrpP

haddock-interfaces:   /usr/share/doc/haskell-iproute/html/iproute.haddock
haddock-html:         /usr/share/doc/haskell-iproute/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-iproute-1.7.15-49-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-iproute.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 iproute
version:              1.7.15
visibility:           public
id:                   iproute-1.7.15-FqEVgqYsctmDMTi9lvGoHU
key:                  iproute-1.7.15-FqEVgqYsctmDMTi9lvGoHU
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             http://www.mew.org/~kazu/proj/iproute/
synopsis:             IP Routing Table
description:
    IP Routing Table is a tree of IP ranges
    to search one of them on the longest
    match base. It is a kind of TRIE with one
    way branching removed. Both IPv4 and IPv6
    are supported.

category:             Algorithms, Network
abi:                  c62fb9a67dfdba416365b5713a4a1e2b
exposed:              True
exposed-modules:
    Data.IP Data.IP.Builder Data.IP.Internal Data.IP.RouteTable
    Data.IP.RouteTable.Internal

hidden-modules:       Data.IP.Addr Data.IP.Mask Data.IP.Op Data.IP.Range
import-dirs:          /usr/lib/ghc-9.4.8/site-local/iproute-1.7.15
library-dirs:         /usr/lib/ghc-9.4.8/site-local/iproute-1.7.15
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/iproute-1.7.15
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-iproute
hs-libraries:         HSiproute-1.7.15-FqEVgqYsctmDMTi9lvGoHU
depends:
    appar-0.1.8-GWpFBSBbC0w8yHmWJHobgf base-4.17.2.1
    byteorder-1.0.4-GnZZPnCtMLjHLa4McP5dl3 bytestring-0.11.5.3
    containers-0.6.7 network-3.1.4.0-18zdZgmnDKE1J4Hp557YCB

haddock-interfaces:   /usr/share/doc/haskell-iproute/html/iproute.haddock
haddock-html:         /usr/share/doc/haskell-iproute/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
